@@ -8,3 +8,5 @@ class AnalysisTarget:
     line_num: int
     lines: List[str]
     file_path: str
+    file_type: str
+    info: str
