@@ -6,18 +6,20 @@ from credsweeper.utils import Util
 
 
 class ValueCamelCaseCheck(Filter):
-    """Check that candidate is not written in camel case"""
+    """Check that candidate is not written in camel case."""
+
     CAMEL_CASE = ["^([a-z]+([A-Z][a-z]+)+)$", "^([A-Z][a-z]+([A-Z][a-z]+)+)$"]
     CAMEL_CASE_PATTERN = regex.compile(Util.get_regex_combine_or(CAMEL_CASE))
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
