@@ -9,7 +9,9 @@ class ValueNotAllowedPatternCheck(Filter):
     """Check that secret doesn't open or closes brackets or a new line."""
 
     NOT_ALLOWED = ["[,<>{};\\]\\[](\\s)*", "(\\s)+[\\\\]", "(\\\\n)(\\s)*"]
-    NOT_ALLOWED_PATTERN = regex.compile(f"{Util.get_regex_combine_or(NOT_ALLOWED)}$", flags=regex.IGNORECASE)
+    NOT_ALLOWED_PATTERN = regex.compile(  #
+        f"{Util.get_regex_combine_or(NOT_ALLOWED)}$",  #
+        flags=regex.IGNORECASE)  # pylint: disable=no-member
 
     def run(self, line_data: LineData) -> bool:
         """Run filter checks on received credential candidate data 'line_data'.
