@@ -5,21 +5,27 @@ from credsweeper.filters import Filter
 
 
 class ValueTokenCheck(Filter):
-    """Split candidate value into substrings using ` ;`{})(<>[]` separators. Check if first substring is shorter than 5
+    """Check if first substring of token is shorter than 5.
+
+    Split candidate value into substrings using ` ;`{})(<>[]` separators. Check if first substring is shorter than 5
+
     Examples:
         "my password"
         "12);password"
+
     """
+
     SPLIT_PATTERN = " |;|\\)|\\(|{|}|<|>|\\[|\\]|`"
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
